@@ -60,8 +60,14 @@ from transformers_keras.sentiment_analysis.dataset import (
     OpinionTermExtractionAndClassificationDataset,
 )
 from transformers_keras.sentiment_analysis.otec import BertForOpinionTermExtractionAndClassification
-from transformers_keras.sequence_classification.dataset import SequenceClassificationDataset, SequenceClassificationExample
-from transformers_keras.sequence_classification.models import AlbertForSequenceClassification, BertForSequenceClassification
+from transformers_keras.sequence_classification.dataset import (
+    SequenceClassificationDataset,
+    SequenceClassificationExample,
+)
+from transformers_keras.sequence_classification.models import (
+    AlbertForSequenceClassification,
+    BertForSequenceClassification,
+)
 from transformers_keras.token_classification.callback import SeqEvalForTokenClassification
 from transformers_keras.token_classification.crf_models import (
     AlertCRFForTokenClassification,
@@ -72,6 +78,6 @@ from transformers_keras.token_classification.dataset import TokenClassificationD
 from transformers_keras.token_classification.models import AlbertForTokenClassification, BertForTokenClassification
 
 __name__ = "transformers_keras"
-__version__ = "0.4.7"
+__version__ = "0.4.8"
 
 logging.basicConfig(format="%(asctime)s %(levelname)7s %(filename)20s %(lineno)4d] %(message)s", level=logging.INFO)
